@@ -583,7 +583,7 @@ class LinuxDevice(object):
         @timeout: How long to wait for the files to be downloaded. Default is
         neveer timeout
         '''
-        cmd = 'scp %s@%s:%s %s' %(self["username"], self["hostname"], filename, localname)
+        cmd = 'scp -o GSSAPIAuthentication=no %s@%s:%s %s' %(self["username"], self["hostname"], filename, localname)
         self.log(cmd, leading = "\033[0;31m$ \033[0m",)
         clild = pexpect.spawn(cmd)
         if self["log_level"] >= LOG_VERBOSE:
@@ -591,7 +591,7 @@ class LinuxDevice(object):
 
         prompt = [pexpect.EOF,
                 pexpect.TIMEOUT,
-                "Are you sure you want to continue connecting",
+                "(?i)are you sure you want to continue connecting",
                 "(?i)password:",
                 "ETA"]
         while True:
@@ -624,11 +624,11 @@ class LinuxDevice(object):
         '''
         self.log("upload: %s@%s:%s <- %s\n" %(self["username"], self["hostname"],
             remotedir, filename), leading = "\033[0;31m$ \033[0m",)
-        clild = pexpect.spawn('scp %s %s@%s:%s' %(filename, self["username"],
+        clild = pexpect.spawn('scp -o GSSAPIAuthentication=no %s %s@%s:%s' %(filename, self["username"],
             self["hostname"], remotedir))
         prompt = [pexpect.EOF,
                 pexpect.TIMEOUT,
-                "Are you sure you want to continue connecting",
+                "(?i)are you sure you want to continue connecting",
                 "(?i)password:",
                 "ETA"]
         while True:
